==> monica-3.7.0p0.tgz: www/monica/resources/lang/zh/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => '提醒:contact',
    'greetings' => '您好:username',
    'want_reminded_of' => '您的提醒事项：:reason',
    'for' => '为：:name',
    'comment' => '备注：:comment',
    'footer_contact_info' => '添加、查看、完成和更改有关此联系人的信息:',
    'footer_contact_info2' => '看看 :name的个人资料',
    'footer_contact_info2_link' => '看看:name的个人资料: :url',

    'notification_subject_line' => '您有一个即将进行的活动',
    'notification_description' => '在:count天后(:date),将有以下事件发生：',

    'stay_in_touch_subject_line' => '您的『常联系』提醒 :name',
    'stay_in_touch_subject_description' => '您的常联系提醒： 每 :frequency 天 与 :name 联系.',

    'notifications_whoops' => '糟了!',
    'notifications_hello' => '您好！',
    'notifications_regards' => '此致',
    'notifications_footer' => '如果您无法点击 ":actionText" 按钮, 复制以下链接至浏览器打开: [:actionURL](:actionURL)',
    'notifications_rights' => '版权所有',

    'confirmation_email_title' => 'Monica – Email 认证',
    'confirmation_email_intro'=> '请点击以下按钮来完成Email认证',
    'confirmation_email_button' => 'Email 认证',
    'confirmation_email_bottom' => '如果不是您本人进行的创建帐户操作，请忽略这封邮件。',

    'password_reset_title' => 'Monica — 重置密码通知',
    'password_reset_intro' => '您收到此邮件是因为我们收到了您的密码重置请求',
    'password_reset_button' => '重置密码',
    'password_reset_expiration' => '此密码重置链接将在 :count 分钟后过期',
    'password_reset_bottom' => '如果您没有请求重置密码，请忽略这封邮件。',

    'invitation_title' => 'Monica — 您收到 :name 的邀请',
    'invitation_intro' => '您已被:name (:email)邀请使用 Monica, 个人社交关系管理工具。',
    'invitation_link' => '要接受邀请，请点击下面的链接：',
    'invitation_button' => '接受邀请',
    'invitation_expiration' => '此链接将在 :count 天后过期',

    'export_title' => 'Your export is ready',
    'export_description' => 'You requested a data export on :date. It is now ready to download.',
    'export_download' => 'Download export',

];

==> monica-4.1.2.tgz: www/monica/resources/lang/zh/mail.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    'subject_line' => '提醒:contact',
    'greetings' => '您好:username',
    'want_reminded_of' => '您的提醒事项：:reason',
    'for' => '为：:name',
    'comment' => '备注：:comment',
    'footer_contact_info' => '添加、查看、完成和更改有关此联系人的信息:',
    'footer_contact_info2' => '看看 :name的个人资料',
    'footer_contact_info2_link' => '看看:name的个人资料: :url',

    'notification_subject_line' => '您有一个即将进行的活动',
    'notification_description' => '在:count天后(:date),将有以下事件发生：',

    'stay_in_touch_subject_line' => '您的『常联系』提醒 :name',
    'stay_in_touch_subject_description' => '您的常联系提醒： 每 :frequency 天 与 :name 联系.',

    'notifications_whoops' => '糟了!',
    'notifications_hello' => '您好！',
    'notifications_regards' => '此致',
    'notifications_footer' => '如果您无法点击 ":actionText" 按钮, 复制以下链接至浏览器打开: [:actionURL](:actionURL)',
    'notifications_rights' => '版权所有',

    'confirmation_email_title' => 'Monica – Email 认证',
    'confirmation_email_intro'=> '请点击以下按钮来完成Email认证',
    'confirmation_email_button' => 'Email 认证',
    'confirmation_email_bottom' => '如果不是您本人进行的创建帐户操作，请忽略这封邮件。',

    'password_reset_title' => 'Monica — 重置密码通知',
    'password_reset_intro' => '您收到此邮件是因为我们收到了您的密码重置请求',
    'password_reset_button' => '重置密码',
    'password_reset_expiration' => '此密码重置链接将在 :count 分钟后过期',
    'password_reset_bottom' => '如果您没有请求重置密码，请忽略这封邮件。',

    'invitation_title' => 'Monica — 您收到 :name 的邀请',
    'invitation_intro' => '您已被:name (:email)邀请使用 Monica, 个人社交关系管理工具。',
    'invitation_link' => '要接受邀请，请点击下面的链接：',
    'invitation_button' => '接受邀请',
    'invitation_expiration' => '此链接将在 :count 天后过期',

    'export_title' => '您的导出已就绪',
    'export_description' => '您请求的导出内容 :date. 已经可以下载了.',
    'export_download' => '下载导出内容',

];
